@@ -14,8 +14,8 @@ if (!all(x$Xnames2 %in% c(colnames(newdata),"intercept"))) stop("see above")
 if (!inherits(newdata, "data.frame")) stop("newdata should be a data.frame object")
 if (!(methInteg %in% c(0,1))) stop("The integration method must be either 0 for Gauss-Hermite or 1 for Monte-Carlo")
 if ((methInteg==0)&(!(nsim %in% c(5,7,9,15,20,30,40,50)))) stop("For Gauss-Hermite integration method, 'nsim' should be either 5,7,9,15,20,30,40 or 50")
-if(missing(var.time)) stop("missing argument 'var.time'")
-if(!(var.time %in% colnames(newdata))) stop("'var.time' should be included in newdata")
+#if(missing(var.time)) stop("missing argument 'var.time'")
+#if(!(var.time %in% colnames(newdata))) stop("'var.time' should be included in newdata")
 
 
 call_fixed <- x$call$fixed[3]
@@ -24,7 +24,7 @@ if(is.null(x$call$classmb)) {call_classmb <- ~-1} else call_classmb <- x$call$cl
 if(is.null(x$call$mixture)) {call_mixture <- ~-1} else call_mixture <- x$call$mixture
 
 
-if(x$conv==1|x$conv==2) {
+if(x$conv==1|x$conv==2|x$conv==3) {
 
 #------------> changement Cecile 10/04/2012
 ## add 12/04/2012
@@ -46,6 +46,12 @@ if(x$Xnames2[1]!="intercept"){
                 }
 
 
+            if(x$conv==3 & draws==TRUE)
+                {
+                    cat("No confidence interval will be provided since the program did not converge properly \n")
+                    draws <- FALSE
+                }
+
 
 
 X1 <- NULL                                                              
@@ -193,13 +199,21 @@ if(length(x$N)>5)
 }
 
 #var.time
-if(var.time %in% colnames(newdata1))
+if(!missing( var.time))
     {
-        times <- newdata1[,var.time,drop=FALSE]
+        if(!(var.time %in% colnames(newdata))) stop("'var.time' should be included in newdata")
+        if(var.time %in% colnames(newdata1))
+            {
+                times <- newdata1[,var.time,drop=FALSE]
+            }
+        else
+            {
+                times <- newdata[,var.time,drop=FALSE]
+            }
     }
 else
     {
-        times <- newdata[,var.time,drop=FALSE]
+        times <- newdata[,1,drop=FALSE]
     }
 
 ## Table sans donnees manquante: newdata
@@ -389,11 +403,28 @@ if (draws){
 ndraws <- as.integer(ndraws)
 ydraws <- NULL
 
-Mat <- matrix(0,ncol=npm,nrow=npm)
-# que la partie sup utilisee donc OK si rien en bas
-Mat[upper.tri(Mat,diag=TRUE)]<- x$V
-Chol <- chol(Mat)
-Chol <- t(Chol)
+            posfix <- eval(x$call$posfix)
+
+            if(ndraws>0)
+                {
+                    Mat <- matrix(0,ncol=npm,nrow=npm)
+                    Mat[upper.tri(Mat,diag=TRUE)]<- x$V
+                    if(length(posfix))
+                        {
+                            Mat2 <- Mat[-posfix,-posfix]
+                            Chol2 <- chol(Mat2)
+                            Chol <- matrix(0,npm,npm)
+                            Chol[setdiff(1:npm,posfix),setdiff(1:npm,posfix)] <- Chol2
+                            Chol <- t(Chol)
+                        }
+                    else
+                        {
+                            Chol <- chol(Mat)
+                            Chol <- t(Chol)
+                        }
+                }
+
+
 
 for (j in 1:ndraws) {
 
